@@ -13,27 +13,33 @@ import PyFWI.seiplot as splt
 from PyFWI.fwi_tools import regularization
 
 class FWI(Wave):
-    """
-    FWI implement full-waveform inversion (FWI)
-    """
-    def __init__(self, d_obs, inpa, src, rec_loc, model_size, n_well_rec, chpr, components, param_functions=None):
+    def __init__(self, d_obs, inpa, src, rec_loc, model_shape, n_well_rec, chpr, components, param_functions=None):
         """
-        This class implement the FWI using the class 'wave_propagator'
-        in 'PyFWI.wave_propagation'.
+        FWI perform full-waveform inversion
 
-        Args:
-            d_obs (dict): Observed data
-            inpa (dict): Dictionary containg required parameters
-            src (class): Source
-            rec_loc (ndarray): Location of the receivers
-            model_size (ndarray): Size of the model
-            n_well_rec ([type]): Number of receivers in the well in INPA['acq_type'] !=1
-            chpr (int): Percentage of specify how much wavefield should be saved.
-            components ([type]): Components of the operation
-            param_functions ([type], optional): A list containg four function in case if the inversion is not happenning in DV parameterization. Defaults to None.
+
+        Parameters
+        ----------
+        d_obs : dict
+            Observed data
+        inpa : dict
+            Input parameters
+        src : Class
+            Source object
+        rec_loc : float
+            Receiver location
+        model_size : tuple
+            Shape of the model
+        n_well_rec : int
+            Number of receivers in the well
+        chpr : flaot (percentage)
+            Percentage for check point 
+        components : int
+            Type of output
+        param_functions : list of function, optional
+            List of functions required in case of inversion with different parameterization than dv, by default None
         """
-    
-        super().__init__(inpa, src, rec_loc, model_size, n_well_rec, chpr, components)
+        super().__init__(inpa, src, rec_loc, model_shape, n_well_rec, chpr, components)
         self.regularization = regularization(self.nx, self.nz, self.dh, self.dh)
         
         if param_functions is None:
@@ -41,11 +47,16 @@ class FWI(Wave):
             self.vec2dict = tools.vec2vel_dict
             self.to_dv = lambda a: a
             self.grad_from_dv = lambda a, b: a
+            self.param_functions_args = []
         else:
             self.dict2vec = param_functions['dict2vec']
             self.vec2dict = param_functions['vec2dict']
             self.to_dv = param_functions['to_dv']
             self.grad_from_dv = param_functions['grad_from_dv']
+            try:
+                self.param_functions_args = param_functions['args']
+            except:
+                self.param_functions_args = []
             
         keys = inpa.keys()
         try:
@@ -68,8 +79,6 @@ class FWI(Wave):
         
         self.fn = inpa['fn']
 
-        self.GN_wave_propagator = Wave(inpa, src, rec_loc, model_size, n_well_rec, chpr, components)
-
         if 'cost_function_type' in keys:
             self.CF = tools.CostFunction(inpa["cost_function_type"])
         else:
@@ -84,20 +93,31 @@ class FWI(Wave):
         
     def __call__(self, m0, method, iter, freqs, n_params, k_0, k_end):
         """
-        FWI implements the full-waveform inversion
+        Calling this object performs the FWI
 
-        Args:
-            m0 (dict): The initial model
-            method (int, str): The optimization method
-            iter (ndarray): An array of iteration for each frequency
-            freqs (float): Frequencies for multi-scale inversion.
-            n_params (int): Number of parameter to invert for in each time
-            k_0 (int): The first parameter of interest
-            k_end (int): The last parameter of interest
+        Parameters
+        ----------
+            m0 : dict
+                The initial model
+            method : int, str
+                The optimization method
+            iter : ndarray)
+                An array of iteration for each frequency
+            freqs : float
+                Frequencies for multi-scale inversion.
+            n_params : int
+                Number of parameter to invert for in each time
+            k_0 : int
+                The first parameter of interest
+            k_end : int
+                The last parameter of interest
 
-        Returns:
-            m_est (dict): The estimated model
-            rms (ndarray): The rms error
+        Returns
+        -------
+            m_est : dictionary
+                The estimated model
+            rms : ndarray
+                The rms error
         """
         m = self.dict2vec(m0)
 
@@ -125,37 +145,6 @@ class FWI(Wave):
 
         return method
 
-    def run(self, m0, method, iter, freqs, n_params, k_0, k_end):
-        """
-        run method performs the FWI
-
-        Parameters
-        ----------
-            m0 : dict
-                The initial model
-            method : int, str
-                The optimization method
-            iter : ndarray)
-                An array of iteration for each frequency
-            freqs : float
-                Frequencies for multi-scale inversion.
-            n_params : int
-                Number of parameter to invert for in each time
-            k_0 : int
-                The first parameter of interest
-            k_end : int
-                The last parameter of interest
-
-        Returns
-        -------
-            m_est : dictionary
-                The estimated model
-            rms : ndarray
-                The rms error
-        """
-        m, rms = self(m0, method, iter, freqs, n_params, k_0, k_end)
-        return m, rms
-
     def lbfgs(self, m0, ITER, freq, n_params=1, k0=0, k_end=1):
         
         n_element = self.nz * self.nx
@@ -188,7 +177,7 @@ class FWI(Wave):
 
         mtotal = np.copy(m0)
         m_old = self.vec2dict(mtotal, self.nz, self.nx)
-        m_new = self.to_dv(m_old)
+        m_new = self.to_dv(m_old, self.param_functions_args)
 
         d_est = self.forward_modeling(m_new, show=False)
         d_est = acq.prepare_residual(d_est, self.sd)
@@ -200,7 +189,7 @@ class FWI(Wave):
         rms = rms_data
 
         grad_dv = self.gradient(adj_src, parameterization='dv')
-        grad = self.grad_from_dv(grad_dv, m_old)
+        grad = self.grad_from_dv(grad_dv, self.param_functions_args, m_old)
         
         params = [*grad]
         grad[params[0]] *= self.grad_coeff[0]
