@@ -676,6 +676,36 @@ def _elastic_model_preparation(model0, med_type):
     return model
 
 
+def disperasion_stability(vp, sdo, fn):
+    """
+    disperasion_stability returns the appropriate parameters for FD 
+    that prevent unstability and dispersion
+
+
+    Parameters
+    ----------
+    vp : float
+        P-wave velocity
+    sdo : int
+        Spatial order of derivation
+    fn : float
+        Nyquist frequency
+
+    Returns
+    -------
+    dh : float
+        Spatial sampling rate
+    dt : float 
+        Temporal sampling rate 
+    """
+    D = fdm(order=sdo)
+    
+    dh = vp.min() / (D.dh_n * fn)    
+    dt = D.dt_computation(vp.max(), dh)
+    
+    return dh, dt
+
+
 def modeling_model(model, med_type):
 
     if med_type in [0, 'acoustic']:
@@ -1596,5 +1626,5 @@ def dict_summation(dict1, dict2, division=1.0):
     return sum_val
 
 if __name__ == "__main__":
-    R = recorder(['vx', 'vz'], 10, 10, 1)
-    print(R.vx)
\ No newline at end of file
+    R = recorder(100, np.array([10]), 10, 1)
+    print(R.vx.shape)
\ No newline at end of file
