@@ -214,14 +214,14 @@ class ModelGenerator(Circular, Laminar):
 
         self.model = None
 
-    def __call__(self, vintage=1, smoothing=0):
+    def __call__(self, **kwargs):
         try:  # in case if there is a model from before, it should be deleted
             self.__dict__.pop('model')
         except:
             pass
         
         # name of the model
-        model = eval("self." + self.name)(vintage, smoothing)
+        model = eval("self." + self.name)(**kwargs)
         self.model = copy.deepcopy(model)
         return model
     
